#
# spec file for package nginx-module-njs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nginx-module-njs
Version:        0.8.1
Release:        1.6
Summary:        NGINX module for NGINX Javascript
License:        BSD-2-Clause
Group:          Productivity/Networking/Web/Proxy
URL:            https://nginx.org/en/docs/njs/
Source:         %{name}.tar.gz
BuildRequires:  nginx-source
%{ngx_conditionals}
%{ngx_requires}

%description
njs is a subset of the JavaScript language that allows extending
nginx functionality.

%prep
%autosetup -p1 -n %{name}
cp -r %{_prefix}/src/nginx .

%build
cd nginx
%{ngx_configure} --add-dynamic-module=.
%make_build modules

%install
mkdir -p %{buildroot}/%{ngx_module_dir}
install -Dpm0755 nginx/objs/ngx_http_js_module.so %{buildroot}/%{ngx_module_dir}
install -Dpm0755 nginx/objs/ngx_stream_js_module.so %{buildroot}/%{ngx_module_dir}

%files
%license LICENSE
%doc README CHANGES
%{ngx_module_dir}/ngx_http_js_module.so
%{ngx_module_dir}/ngx_stream_js_module.so

%changelog
* Thu Oct 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.8.1:
  * Implement a number of useful language facilities around shared
    dictionaries, add more global nginx properties, and
    configuration directives (js_periodic, js_shared_dict_zone)
  * Possibly incompatible change: native methods are provided with
    retval argument. This change breaks compatibility with C
    extension for njs requiring the modification of the code.
  * A number of non-compliant deprecated String methods were
    removed
* Tue May  2 2023 Adam Majer <adam.majer@suse.de> 0.7.12
- update to 0.7.12
  nginx modules:
  * ) Bugfix: fixed Headers() constructor in Fetch API.
  Core:
  * ) Feature: added Hash.copy() method in "crypto" module.
  * ) Feature: added "zlib" module.
  * ) Improvement: added support for export {name as default}
    statement.
  * ) Bugfix: fixed Number constructor according to the spec.
  - Changes with njs 0.7.11
  nginx modules:
  * ) Bugfix: added missed linking with libxml2 for the dynamic module.
    The bug was introduced in 0.7.10.
  Core:
  * ) Feature: added XMLNode API to modify XML documents.
  * ) Change: removed XML_PARSE_DTDVALID during parsing of XML document
    due to security implications. The issue was introduced
    in 0.7.10. When XML_PARSE_DTDVALID is enabled, libxml2 parses and
    executes external entities present inside an XML document.
  * ) Bugfix: fixed the detection of await in arguments.
  * ) Bugfix: fixed Error() instance dumping when "name" prop is not
    primitive.
  * ) Bugfix: fixed array instance with a getter property dumping.
  * ) Bugfix: fixed njs_object_property() with NJS_WHITEOUT properties.
  * ) Bugfix: fixed func instance dumping with "name" as getter.
  * ) Bugfix: fixed attaching of a stack to an error object.
  * ) Bugfix: fixed String.prototype.replace() with replacement containing
    "$'", "$`".
* Thu Feb 23 2023 Adam Majer <adam.majer@suse.de> 0.7.10
- Initial package
